@@ -6,7 +6,7 @@ from string import ascii_lowercase, ascii_uppercase, digits
 from random import randint, shuffle
 from flask import current_app, session, request, url_for, json
 from eoleflask.util import get_proxy_url
-from werkzeug import secure_filename
+from werkzeug.utils import secure_filename
 from email.mime.text import MIMEText
 
 COMMASPACE = ', '
@@ -50,9 +50,8 @@ def send_mail(smtp_server="", mailFrom="", mailTo=[], mailSubject="", text=""):
         orig_timeout = smtplib.socket.getdefaulttimeout()
         try:
             smtplib.socket.setdefaulttimeout(10)
-            s = smtplib.SMTP(smtp_server)
+            s = smtplib.SMTP("127.0.0.1")
             s.sendmail("root@localhost.{}".format(current_app.config['DOMAINE_MAIL']), mailTo, msg.as_string())
-
             s.quit()
         except Exception as err:
             current_app.logger.error("Problème lors de l'envoi des mail : {0}".format(err))
@@ -81,6 +80,14 @@ def est_admin():
     proxy = xmlrpc.client.ServerProxy(current_app.config["CONTROLEVNC_URL"])
     return  proxy.remote_est_admin(username)
 
+def est_admin_etab():
+    """Returns true if username is an admin
+    """
+    username = session.get('username', None)
+    secret = current_app.config["SECRET_KEY"]
+    proxy =  xmlrpc.client.ServerProxy(current_app.config["CONTROLEVNC_URL"])
+    return  proxy.remote_est_admin_etab(username)
+
 def user_get_attr(attr, user=None):
     """Returns the given attribute <attr> in ldap for user <user>
        if user is None then the current logged user is used
@@ -92,6 +99,16 @@ def user_get_attr(attr, user=None):
         user = username
     return proxy.remote_get_attr(secret, username, user, attr)
 
+def users_get_attr(attr, users):
+    """Returns the given attribute <attr> in ldap for users [<user>]
+    """
+    smtplib.socket.setdefaulttimeout(120)
+
+    username = session.get('username', None)
+    secret = current_app.config["SECRET_KEY"]
+    proxy = xmlrpc.client.ServerProxy(current_app.config["CONTROLEVNC_URL"])
+    return proxy.remote_get_attr(secret, username, users, attr)
+
 def get_user_menus():
     """Return the menus allowed for the current user
     """
@@ -125,9 +142,15 @@ def get_user_menus():
                         for menu_item in config['items']:
                             main_menu = menu_item['top-menu']
                             for menu in menus:
-                                if menu['name'] == main_menu:
-                                    menu['menu-items'].append(menu_item['menu-item'])
+                                active = True
+                                if "active" in menu_item['menu-item'] :
+                                    if  menu_item['menu-item']["active"] == "false":
+                                        active = False
+                                if active:
+                                    if menu['name'] == main_menu:
+                                        menu['menu-items'].append(menu_item['menu-item'])
                     except Exception as e:
+
                         current_app.logger.warning('The configuration file content does not match the expected syntax, the menu will not be created!')
 
                 except Exception as e:
@@ -143,7 +166,7 @@ def get_user_menus():
 
         # used to map the names to the typeadmin values
         typeadmin = ["prof", "admin", "prof_admin"]
-
+        etabadmin = est_admin_etab()
         session["menus"] = []
         prepath = get_proxy_url(request, url_for("index.show", _external=True)).replace("/index", "")
         for menu in menus:
@@ -154,6 +177,12 @@ def get_user_menus():
                         if prepath not in item["link"]:
                             item["link"] = prepath + item["link"]
                     items.append(item)
+                if "etab_admin" in item :
+                    if etabadmin and ("etab_admin" in item["etab_admin"]):
+                        if "link" in item:
+                            if prepath not in item["link"]:
+                                item["link"] = prepath + item["link"]
+                        items.append(item)
             if len(items) > 0:
                 if "link" in menu:
                     if prepath not in menu["link"]:
